@@ -17,10 +17,10 @@ use Memoize qw(memoize);
 
 #memoize('_get_video_info');
 memoize('_ytdl_is_available');
-memoize('_info_from_ytdl');
 
+#memoize('_info_from_ytdl');
 #memoize('_extract_from_ytdl');
-memoize('_extract_from_invidious');
+#memoize('_extract_from_invidious');
 
 use parent qw(
   WWW::YoutubeViewer::Search
@@ -44,7 +44,7 @@ WWW::YoutubeViewer - A very easy interface to YouTube.
 
 =cut
 
-our $VERSION = '3.11.3';
+our $VERSION = '3.11.6';
 
 =head1 SYNOPSIS
 
@@ -828,8 +828,16 @@ sub _extract_from_ytdl {
         foreach my $format (@{$ref->{formats}}) {
             if (exists($format->{format_id}) and exists($format->{url})) {
 
+                my $id = $format->{format_id};
+
+                # Keep only the default audio track
+                if ($id =~ /(^[0-9]+)-[0-9]/) {
+                    $id = $1;
+                    $format->{format_note} =~ /\(default\)/ or next;
+                }
+
                 my $entry = {
-                             itag => $format->{format_id},
+                             itag => $id,
                              url  => $format->{url},
                              type => ((($format->{format} // '') =~ /audio only/i) ? 'audio/' : 'video/') . $format->{ext},
                             };
@@ -871,7 +879,7 @@ sub _fallback_extract_urls {
         say STDERR ":: Using invidious to extract the streaming URLs...";
     }
 
-    push @formats, $self->_extract_from_invidious($videoID);
+    # push @formats, $self->_extract_from_invidious($videoID);
 
     if ($self->get_debug) {
         my $count = scalar(@formats);
@@ -1058,7 +1066,7 @@ sub _get_youtubei_content {
 
     require Time::Piece;
 
-    my $android_useragent = 'com.google.android.youtube/18.11.34 (Linux; U; Android 11) gzip';
+    my $android_useragent = 'com.google.android.youtube/20.10.38 (Linux; U; Android 11) gzip';
 
     my %android = (
                    "videoId" => $videoID,
@@ -1067,7 +1075,7 @@ sub _get_youtubei_content {
                                               'hl'                => 'en',
                                               'gl'                => 'US',
                                               'clientName'        => 'ANDROID',
-                                              'clientVersion'     => '18.11.34',
+                                              'clientVersion'     => '20.10.38',
                                               'androidSdkVersion' => 30,
                                               'userAgent'         => $android_useragent,
                                               %args,
@@ -1319,7 +1327,8 @@ sub get_streaming_urls {
     }
 
     # Try again with yt-dlp / youtube-dl
-    if (   !@streaming_urls
+    if (   1
+        or !@streaming_urls
         or (($json->{playabilityStatus}{status} // '') =~ /fail|error|unavailable|not available/i)
         or $self->get_force_fallback
         or (($json->{videoDetails}{videoId} // '') ne $videoID)) {
